@@ -48,10 +48,17 @@
 #' @param forms A character vector of REDCap instrument names that specifies
 #' which instruments to import. Default is `NULL` which imports all instruments
 #' in the project.
-#' @param export_survey_fields A logical that specifies whether to export the
-#' survey identifier and timestamp fields if available. Default is `TRUE`.
+#' @param export_survey_fields A logical that specifies whether to export
+#' survey identifier and timestamp fields. The default, `NULL`,
+#' tries to determine if survey fields exist and returns them if available.
+#' @param export_data_access_groups A logical that specifies whether to export
+#' the data access group field. The default, `NULL`, tries to determine if a data
+#' access group field exists and returns it if available.
 #' @param suppress_redcapr_messages A logical to control whether to suppress messages
 #' from REDCapR API calls. Default `TRUE`.
+#' @param guess_max A positive [base::numeric] value
+#' passed to [readr::read_csv()] that specifies the maximum number of records to
+#' use for guessing column types. Default `.Machine$integer.max`.
 #'
 #' @examples
 #' \dontrun{
@@ -71,14 +78,17 @@ read_redcap <- function(redcap_uri,
                         token,
                         raw_or_label = "label",
                         forms = NULL,
-                        export_survey_fields = TRUE,
-                        suppress_redcapr_messages = TRUE) {
+                        export_survey_fields = NULL,
+                        export_data_access_groups = NULL,
+                        suppress_redcapr_messages = TRUE,
+                        guess_max = .Machine$integer.max) {
   check_arg_is_character(redcap_uri, len = 1, any.missing = FALSE)
   check_arg_is_character(token, len = 1, any.missing = FALSE)
   check_arg_is_valid_token(token)
   check_arg_choices(raw_or_label, choices = c("label", "raw"))
   check_arg_is_character(forms, min.len = 1, null.ok = TRUE, any.missing = FALSE)
-  check_arg_is_logical(export_survey_fields, len = 1, any.missing = FALSE)
+  check_arg_is_logical(export_survey_fields, len = 1, any.missing = FALSE, null.ok = TRUE)
+  check_arg_is_logical(export_data_access_groups, len = 1, any.missing = FALSE, null.ok = TRUE)
   check_arg_is_logical(suppress_redcapr_messages, len = 1, any.missing = FALSE)
 
   # Load REDCap Metadata ----
@@ -150,6 +160,17 @@ read_redcap <- function(redcap_uri,
     )
   }
 
+  # Determine fields to pass to REDCapR ----
+  # Enforce NULL opinionated checks for select arguments supplied:
+  # - export_data_access_groups
+  # - export_survey_fields
+
+  export_data_access_groups_original <- export_data_access_groups
+  export_data_access_groups <- ifelse(is.null(export_data_access_groups), TRUE, export_data_access_groups)
+
+  export_survey_fields_original <- export_survey_fields
+  export_survey_fields <- ifelse(is.null(export_survey_fields), TRUE, export_survey_fields)
+
   # Load REDCap Dataset output ----
 
   db_data <- try_redcapr({
@@ -158,13 +179,34 @@ read_redcap <- function(redcap_uri,
       token = token,
       forms = forms_for_api_call,
       export_survey_fields = export_survey_fields,
-      verbose = !suppress_redcapr_messages
+      export_data_access_groups = export_data_access_groups,
+      verbose = !suppress_redcapr_messages,
+      guess_max = guess_max
     )
   })
 
   # Check that results were returned
   check_redcap_populated(db_data)
 
+  # Check whether DAGs or survey fields are present in the project, if requested
+  if (!is.null(export_data_access_groups_original)) {
+    if (export_data_access_groups_original) {
+      check_data_arg_exists(db_data,
+        col = "redcap_data_access_group",
+        arg = "export_data_access_groups"
+      )
+    }
+  }
+
+  if (!is.null(export_survey_fields_original)) {
+    if (export_survey_fields_original) {
+      check_data_arg_exists(db_data,
+        col = "redcap_survey_identifier",
+        arg = "export_survey_fields"
+      )
+    }
+  }
+
   # Apply database output changes ----
   # Apply checkbox appending functions to metadata
   db_metadata <- update_field_names(db_metadata)
