@@ -148,4 +148,78 @@ test_that("checkmate wrappers work", {
   # token
   expect_error(check_arg_is_valid_token("abc"), class = "invalid_token")
   expect_true(check_arg_is_valid_token("123456789ABCDEF123456789ABCDEF01"))
+
+  # extension
+  expect_warning(check_arg_is_valid_extension("temp.docx", valid_extensions = "xlsx"),
+    class = "invalid_file_extension"
+  )
+  expect_warning(check_arg_is_valid_extension("xlsx.", valid_extensions = "xlsx"),
+    class = "invalid_file_extension"
+  )
+  expect_true(check_arg_is_valid_extension("temp.xlsx", valid_extensions = "xlsx"))
+})
+
+test_that("check_data_arg_exists works", {
+  missing_fields <- tibble::tribble(
+    ~record_id, ~field_1,
+    1,          "1"
+  )
+
+  included_fields <- tibble::tribble(
+    ~record_id, ~redcap_data_access_group, ~redcap_survey_identifier, ~field_1,
+    1, "A", NA, "1"
+  )
+
+  expect_error(
+    check_data_arg_exists(
+      db_data = missing_fields,
+      col = "redcap_data_access_group",
+      arg = "export_data_access_groups"
+    ),
+    class = "nonexistent_arg_requested"
+  )
+  expect_no_error(
+    check_data_arg_exists(
+      db_data = included_fields,
+      col = "redcap_data_access_group",
+      arg = "export_data_access_groups"
+    ),
+    class = "nonexistent_arg_requested"
+  )
+  expect_error(
+    check_data_arg_exists(
+      db_data = missing_fields,
+      col = "redcap_survey_identifier",
+      arg = "export_survey_fields"
+    ),
+    class = "nonexistent_arg_requested"
+  )
+  expect_no_error(
+    check_data_arg_exists(
+      db_data = included_fields,
+      col = "redcap_survey_identifier",
+      arg = "export_survey_fields"
+    ),
+    class = "nonexistent_arg_requested"
+  )
+})
+
+test_that("check_file_exists works", {
+  withr::with_tempdir({
+    dir <- getwd()
+    filepath <- paste0(dir, "/temp.csv")
+    expect_no_error(
+      check_file_exists(file = filepath, overwrite = FALSE)
+    )
+  })
+
+  withr::with_tempdir({
+    dir <- getwd()
+    tempfile <- write.csv(x = mtcars, file = "temp.csv")
+    filepath <- paste0(dir, "/temp.csv")
+    expect_error(
+      check_file_exists(file = filepath, overwrite = FALSE),
+      class = "check_file_overwrite"
+    )
+  })
 })
