@@ -260,8 +260,32 @@ test_that("try_redcapr works", {
   try_redcapr(list(success = FALSE, status_code = 405)) %>%
     expect_error(class = "cannot_post")
 
-  try_redcapr(list(success = FALSE, status_code = "")) %>%
-    expect_error(class = "unexpected_error")
+  try_redcapr(list(
+    success = FALSE,
+    status_code = "",
+    outcome_message = "The REDCap project no longer exists because it was deleted."
+  )) %>%
+    expect_error(class = "deleted_project")
+
+  # Unexpected error, no message
+  cnd <- try_redcapr(list(success = FALSE, status_code = "")) %>%
+    catch_cnd()
+  expect_s3_class(cnd, "unexpected_error")
+  expect_null(cnd$parent)
+
+  # Unexpected error, w/ message
+  cnd <- try_redcapr(list(success = FALSE, status_code = "", outcome_message = "some error")) %>%
+    catch_cnd()
+  expect_s3_class(cnd, "unexpected_error")
+  expect_equal(cnd$parent$message, "some error")
+
+  # Unexpected error, w/ message, works with multiline expr
+  cnd <- try_redcapr({
+    list(success = FALSE, status_code = "", outcome_message = "some error")
+  }) %>%
+    catch_cnd()
+  expect_s3_class(cnd, "unexpected_error")
+  expect_equal(cnd$parent$message, "some error")
 
   try_redcapr(list(success = TRUE, data = as.numeric("A"))) %>%
     expect_warning(class = "unexpected_warning")
@@ -362,3 +386,28 @@ test_that("remove_empty_rows works", {
     remove_empty_rows(my_record_id) %>%
     expect_equal(expected_out)
 })
+
+test_that("is_labelled works", {
+  df <- tibble::tribble(
+    ~"one", ~"two", ~"three",
+    1, 2, 3
+  )
+
+  is_labelled <- is_labelled(df)
+  expect_false(is_labelled)
+
+  labels <- c("One", "Two", "Three")
+  labelled::var_label(df) <- labels
+
+  is_labelled <- is_labelled(df)
+  expect_true(is_labelled)
+})
+
+test_that("make_skimr_labels works", {
+  skimr_labels <- make_skimr_labels()
+
+  # Test for named character vector output
+  expect_true(is.vector(skimr_labels))
+  expect_true(is.character(skimr_labels))
+  expect_true(!is.null(attr(skimr_labels, "name")))
+})
